@@ -6,8 +6,8 @@ from typing import List, Optional
 import boto3
 from aws_assume_role_lib import assume_role
 from dataclasses_json import dataclass_json
-from smart_open import open
 
+from .s3 import write_file
 from .sink import Sink
 
 logger = logging.getLogger()
@@ -18,7 +18,7 @@ logger.setLevel(logging.INFO)
 @dataclass
 class FileSinkConfig:
     # Location of the sink file. Can be local file or s3://bucket/object
-    output: str
+    path: str
 
     # IAM role to assume before writing to file
     assume_role_arn: Optional[str] = None
@@ -28,7 +28,7 @@ class FileSink(Sink):
     """File sink functions"""
 
     def __init__(self, config: FileSinkConfig):
-        self.output = config.output
+        self.path = config.path
 
         session = boto3.Session()
         if config.assume_role_arn is not None:
@@ -36,20 +36,5 @@ class FileSink(Sink):
 
     def _sink(self, messages: List[dict]) -> bool:
         """Write records to file"""
-
-        # Give S3 bucket owner full control over the new object
-        # See https://github.com/RaRe-Technologies/smart_open/blob/develop/howto.md#how-to-pass-additional-parameters-to-boto3
-        params = None
-        if self.output.startswith("s3://"):
-            params = {
-                "client_kwargs": {
-                    "S3.Client.create_multipart_upload": {
-                        "ACL": "bucket-owner-full-control"
-                    }
-                }
-            }
-
-        with open(self.output, "w", transport_params=params) as fp:
-            json.dump(messages, fp)
-
+        write_file(self.path, json.dumps(messages))
         return True
