@@ -11,10 +11,7 @@ except ImportError:
     print("Please install metaphor[looker] extra\n")
     raise
 
-from metaphor.common.event_util import EventUtil
-from metaphor.common.extractor import BaseExtractor, RunConfig
-from metaphor.common.metadata_change_event import (
-    AspectType,
+from metaphor.models.metadata_change_event import (
     Chart,
     ChartType,
     Dashboard,
@@ -23,9 +20,11 @@ from metaphor.common.metadata_change_event import (
     DashboardPlatform,
     DashboardUpstream,
     DataPlatform,
-    EntityType,
     MetadataChangeEvent,
 )
+
+from metaphor.common.event_util import EventUtil
+from metaphor.common.extractor import BaseExtractor, RunConfig
 from metaphor.looker.lookml_parser import Connection, Model, parse_models
 
 logger = logging.getLogger()
@@ -47,6 +46,10 @@ class LookerRunConfig(RunConfig):
 class LookerExtractor(BaseExtractor):
     """Looker metadata extractor"""
 
+    @staticmethod
+    def config_class():
+        return LookerRunConfig
+
     # From https://docs.looker.com/setup-and-management/database-config
     dialect_platform_map = {
         "snowflake": DataPlatform.SNOWFLAKE,
@@ -86,7 +89,7 @@ class LookerExtractor(BaseExtractor):
         return looker_sdk.init31()
 
     async def extract(self, config: RunConfig) -> List[MetadataChangeEvent]:
-        assert isinstance(config, LookerRunConfig)
+        assert isinstance(config, LookerExtractor.config_class())
 
         logger.info("Fetching metadata from Looker")
 
@@ -132,7 +135,6 @@ class LookerExtractor(BaseExtractor):
             dashboard = sdk.dashboard(dashboard_id=basic_dashboard.id)
 
             dashboard_info = DashboardInfo()
-            dashboard_info.aspect_type = AspectType.DASHBOARD_INFO
             dashboard_info.title = dashboard.title
             dashboard_info.description = dashboard.description
             dashboard_info.url = (
@@ -152,7 +154,6 @@ class LookerExtractor(BaseExtractor):
 
             dashboards.append(
                 Dashboard(
-                    entity_type=EntityType.DASHBOARD,
                     logical_id=DashboardLogicalID(
                         dashboard.id, DashboardPlatform.LOOKER
                     ),
@@ -212,8 +213,6 @@ class LookerExtractor(BaseExtractor):
         return (
             charts,
             DashboardUpstream(
-                aspect_type=AspectType.DASHBOARD_UPSTREAM,
                 source_datasets=list(dataset_ids),
-                sources=[],  # TODO: Remove after the deprecated field is dropped
             ),
         )
